function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactRouterDom = require('react-router-dom');

var Auth = React__default.createContext(null);
var AuthContextProvider = Auth.Provider;
var AuthContext = Auth;

var TokenObject = /*#__PURE__*/function () {
  function TokenObject(tokenName) {
    this.tokenName = tokenName;
  }

  var _proto = TokenObject.prototype;

  _proto.isTokenExpire = function isTokenExpire() {
    if (this.isTokenExist()) {
      var _e = JSON.parse(localStorage[this.tokenName]).expiresAt;
      return _e < new Date();
    } else {
      return true;
    }
  };

  _proto.isTokenExist = function isTokenExist() {
    return localStorage[this.tokenName] !== undefined;
  };

  _proto.setToken = function setToken(value, expiresAt) {
    var json = {
      value: value,
      expiresAt: expiresAt
    };
    localStorage[this.tokenName] = JSON.stringify(json);
  };

  _proto.getToken = function getToken() {
    if (this.isTokenExist()) {
      if (!this.isTokenExpire()) {
        var _t = JSON.parse(localStorage[this.tokenName]);

        var token = _t.value;
        var expiresAt = _t.expiresAt;
        return {
          authToken: token,
          expireAt: expiresAt
        };
      } else {
        return {
          authToken: null,
          expireAt: null
        };
      }
    } else {
      return {
        authToken: null,
        expireAt: null
      };
    }
  };

  _proto.removeToken = function removeToken() {
    localStorage.removeItem(this.tokenName);
  };

  return TokenObject;
}();

var AuthProvider = function AuthProvider(_ref) {
  var cookieName = _ref.cookieName,
      children = _ref.children;
  var JwtToken = new TokenObject(cookieName);

  var _useState = React.useState(JwtToken.getToken()),
      authObject = _useState[0],
      setAuthObject = _useState[1];

  React.useEffect(function () {
    if (authObject.authToken === undefined || authObject.authToken === null || authObject.expireAt === null) {
      JwtToken.removeToken();
    } else {
      JwtToken.setToken(authObject.authToken, authObject.expireAt);
    }
  }, [authObject]);
  return /*#__PURE__*/React__default.createElement(AuthContextProvider, {
    value: {
      authObject: authObject,
      setAuthToken: setAuthObject
    }
  }, children);
};

AuthProvider.defaultProps = {
  cookieName: "_authUser"
};

var isAuth = function isAuth() {
  var value = React.useContext(AuthContext);

  if ((value === null || value === void 0 ? void 0 : value.authObject.authToken) && (value === null || value === void 0 ? void 0 : value.authObject.expireAt)) {
    if (value.authObject.expireAt < new Date()) {
      return {
        auth: true,
        authToken: value.authObject.authToken
      };
    } else {
      value.setAuthToken({
        authToken: null,
        expireAt: null
      });
      return {
        auth: false,
        authToken: null
      };
    }
  } else {
    return {
      auth: false,
      authToken: null
    };
  }
};

var PrivateRoute = function PrivateRoute(_ref) {
  var component = _ref.component,
      loginPath = _ref.loginPath,
      path = _ref.path;

  var _isAuth = isAuth(),
      auth = _isAuth.auth;

  if (auth) {
    return /*#__PURE__*/React__default.createElement(reactRouterDom.Route, {
      component: component,
      path: path
    });
  } else {
    return /*#__PURE__*/React__default.createElement(reactRouterDom.Redirect, {
      to: loginPath
    });
  }
};

var loginAuth = function loginAuth(token, expiresIn) {
  var expTime = new Date(new Date().getTime() + expiresIn * 60 * 1000);

  try {
    var c = React.useContext(AuthContext);
    c.setAuthToken({
      authToken: token,
      expireAt: expTime
    });
    return true;
  } catch (e) {
    return false;
  }
};
var logoutAuth = function logoutAuth() {
  try {
    var c = React.useContext(AuthContext);

    if (c === null || c === void 0 ? void 0 : c.authObject.authToken) {
      c.setAuthToken({
        authToken: null,
        expireAt: null
      });
      return true;
    } else {
      return false;
    }
  } catch (e) {
    return false;
  }
};

var authHeader = function authHeader() {
  var c = React.useContext(AuthContext);

  if (c.authObject.authToken) {
    return "Bearer " + c.authObject.authToken;
  } else {
    return null;
  }
};

exports.AuthProvider = AuthProvider;
exports.PrivateRoute = PrivateRoute;
exports.authHeader = authHeader;
exports.isAuth = isAuth;
exports.loginAuth = loginAuth;
exports.logoutAuth = logoutAuth;
//# sourceMappingURL=index.js.map
